/* SPDX-License-Identifier: MIT */
/* SPDX-FileCopyrightText: (c) Copyright 2024 Andrew Bower <andrew@bower.uk> */

#ifndef _PRECREATE_H
#define _PRECREATE_H

extern int precreate_dir(const char *area, mode_t mode, uid_t owner, uid_t group);

#endif
